<?php

	add_image_size( 'home-page-banner', 9999, 400, true );

/**
 * Initialize Class
 *
 * @since 1.0.0
 *
 * @param null
 * @return null
 * @package WordPress
 */

class UBC_WP_CLF_Lite {

	/**
	 * Set up our actions and filters
	 *
	 * @since 1.0.0
	 *
	 * @param null
	 * @return void
	 * @package WordPress
	 */
	public function init() {

		// Adds excerpt to pages
		add_action( 'init', array( $this, 'my_add_excerpts_to_pages' ), 10, 2 );
		// Add the notes form
		add_action( 'wp_clf_lite_sidebar_notes', array( $this, 'wp_clf_lite_sidebar_notes__notes_form' ) );
		// Add the Handouts tab
		add_action( 'wp_clf_lite_sidebar_handouts', array( $this, 'wp_clf_lite_sidebar_handouts__handouts_markup' ) );
		// Add do action for course section listings
		add_action( 'sections_page_listing', array( $this, 'course_sidebar_sections_list_sections' ), 10, 2 );
		// Add to show courses sections and child sections listings
		add_action( 'sections_course_main_listing', array( $this, 'list_sections_with_subsections' ), 10, 2 );

		// Filters
		// surrounds specified oembed content with html
		add_filter( 'embed_oembed_html', array( $this, 'tdd_oembed_filter' ), 99, 4 );
		// Teeny mce remove buttons
		add_filter( 'teeny_mce_buttons', array( $this, 'remove_buttons_tinymce' ) );
		// teeny mce_hacking
		add_filter( 'teeny_mce_before_init', array( $this, 'style_frontend_tinyce' ) );

		add_filter( 'template_include', array( $this, 'ubc_courses_spaces_redirect_template_front_page_course_sections' ) );
		add_filter( 'bbp_topic_admin_links', array( $this, 'ubc_wp_clf_lite_bbp_admin_links' ), 10, 2 );

	}/* init() */

	/**
	 * Adding excerpts to pages
	 *
	 * @since 1.0.0
	 * @return null
	 */

	public function my_add_excerpts_to_pages() {

		add_post_type_support( 'page', 'excerpt' );

	}

	/*  add html around specified oembed objects tdd_oembed_filter() */

	function tdd_oembed_filter($html, $url, $attr, $post_ID) {

		if ( strpos( $html, 'youtube' ) !== false || strpos( $html, 'vimeo' ) !== false  ) :

		 	return  '<div class="flex-video">'.$html.'</div>';

		else :

			return $html;

	endif;

	}/* tdd_oembed_filter() */

	/**
	 * The markup for the notes form in the sidebar.
	 *
	 * @since 1.0.0
	 *
	 * @param null
	 * @return null
	 */

	function wp_clf_lite_sidebar_notes__notes_form() {

		$site_url = site_url();

		if ( ! is_user_logged_in() ) {
			$login_url = wp_login_url( get_permalink() );
			echo '<div class="no-notes column-12">';
			$sign_in_link = '<a class="button tiny hollow" href="' . $login_url . '" title="">' . __( 'sign in', 'ubc-wp-clf-lite' ) . '</a>';
			echo wp_kses_post( sprintf( _x( 'Notes only available if you %s', '%s = sign in link', 'ubc-wp-clf-lite' ), $sign_in_link ) );
			echo '</div>';
			return;
		}

		global $post;

		// Fetch the actual form from CMB2
		$form = cmb2_get_metabox_form( 'ubc_user_notes_metabox', $post->ID );

		if ( ! empty( $form ) ) {

			echo $form;

		} else {

			echo 'Something has gone terribly wrong.';

		}

	}/* wp_clf_lite_sidebar_notes__notes_form() */


	/**
	 * Helper function to get the handouts attached to a subsection
	 *
	 * @since 1.0.0
	 *
	 * @param (Object|Int) $post - A WP_Post Object or a post ID
	 * @return (false|array) - The handouts attached to the passed subsection, false if none found
	 */

	public static function get_handouts_for_subsection( $post ) {

		// If what is passed is not a WP_Post object, assume a post ID
		if ( ! is_a( $post, 'WP_Post' ) ) {
			$section_post_id = absint( $post );
		}

		$section_post_id = $post->ID;

		if ( empty( $section_post_id ) ) {
			return apply_filters( 'ubc_wp_clf_lite_handouts_for_subsection', false );
		}

		$component_associations = get_post_meta( $section_post_id, 'component_associations', true );

		if ( empty( $component_associations ) || ! is_array( $component_associations ) ) {
			return apply_filters( 'ubc_wp_clf_lite_handouts_for_subsection', false );
		}

		$handouts = array();

		// Test if any of these are handouts
		foreach ( $component_associations as $id => $post_id ) {

			$post_type = get_post_type( $post_id );
			if ( 'handout' !== $post_type ) {
				continue;
			}

			$handouts[ $post_id ] = array(

				'title' => get_the_title( $post_id ),
				'fields' => \UBC\Press\Utils::get_handout_content( $post_id ),

			);

		}

		if ( empty( $handouts ) ) {
			return apply_filters( 'ubc_wp_clf_lite_handouts_for_subsection', false );
		}

		return apply_filters( 'ubc_wp_clf_lite_handouts_for_subsection', $handouts );

	}/* get_handouts_for_subsection() */

	/**
	 * The main sidebar contains 3 tabs; Sections, Handouts and Notes
	 * This is the markup for the 2nd tab - Handouts. IT displays a list
	 * of the handouts that are for the currently shown subsection.
	 *
	 * @since 1.0.0
	 *
	 * @param null
	 * @return null
	 */

	public function wp_clf_lite_sidebar_handouts__handouts_markup() {

		global $post;

		if ( ! is_a( $post, 'WP_Post' ) ) {
			return;
		}

		$handouts = static::get_handouts_for_subsection( $post );

		if ( false === $handouts ) {
			// echo esc_html( 'No Handouts available', 'ubc-wp-clf-lite' );
			return;
		}

		$startPath = trailingslashit( dirname( __FILE__ ) ) . 'template-parts';
		$templateNames = 'handout-tab-single.php';

		foreach ( $handouts as $id => $handout_items ) {
			\UBC\Helpers::locate_template_part_in_plugin( $startPath, $templateNames, true, false, $handout_items );
		}

	}/* wp_clf_lite_sidebar_handouts__handouts_markup() */


	/**
	 * Courses sidebar sections page list. Sets up loop query $sections_list_query and includes template courses-section-list.php
	 *
	 * @since 1.0.0
	 *
	 * @param null
	 * @return null
	 */

	public function course_sidebar_sections_list_sections() {

		require_once( trailingslashit( get_stylesheet_directory() ) . '/inc/sidebar-sub-section-list.php' );

	}/* course_sidebar_sections_list_sections */

	/**
	 * List sections with subsections.
	 *
	 * @since 1.0.0
	 *
	 * @param null
	 * @return null
	 */

	public function list_sections_with_subsections() {

		require_once( trailingslashit( get_stylesheet_directory() ) . '/inc/sub-section-list.php' );

	}/* list_sections_with_subsections() */

	/**
	 * Remove unused scripts from Teeny mce
	 *
	 * @since 0.1.9
	 * @return $in = array of avaible options for teeny MCE
	 */
	public function style_frontend_tinyce( $in ) {

		if ( ! is_admin() ) :

			// $in['plugins'] = 'fullscreen';

				return $in;

		endif;

	}

	/**
	 * Remove buttons from teeny mce
	 *
	 * @since 0.1.9
	 * @param $buttons = array of avaible buttons
	 * @return $remove = array of button to remove
	 */
	public function remove_buttons_tinymce( $buttons ) {

		if ( ! is_admin() ) :

			//Remove unwanted buttons
			$remove = array( 'blockquote', 'alignleft', 'strikethrough', 'aligncenter', 'alignright', 'undo', 'redo', 'link', 'unlink', 'underline' );

				return array_diff( $buttons, $remove );

		endif;

	}

	/**
	* Redirect template to front-page.php if sections is selected in get_options( 'show_on_front' ).
	*
	* @since 0.1.16
	* @return $template - (string) The path of the template to include
	*/

	public function ubc_courses_spaces_redirect_template_front_page_course_sections( $template ) {

		// Will need the vaule from get option show on front.
		$site_option_show_on_front 	= get_option( 'show_on_front' );

		// Will need this to make sure we are not on a dashboard.
		$dashboard_page = get_query_var( 'studentdashboard' );

		if ( 'sections' === $site_option_show_on_front && is_home() && 'yes' == ! $dashboard_page ) :

			$section_front_page_template = locate_template( array( 'front-page.php' ) );

			if ( ! empty( $section_front_page_template ) ) :

				return $section_front_page_template;

			endif;

		endif;

			return $template;

	} /* ubc_courses_spaces_redirect_template_front_page_course_sections( $template ) */

	/**
	* A switch statement used to show what the admin has selected to name groups of course content
	* get_theme_mod info found in /inc/customizer-ubc-wp-clf-lite.php
	*
	* @since 0.1.16
	* @return $section_name - (string)
	*/

	static public function get_course_content_name_convention() {

		$section_name_conv 			= get_theme_mod( 'section_name_convention' );
		$section_name_custom 		= get_theme_mod( 'section_name_convention_custom' );

		switch ( $section_name_conv ) :

			case 'module' :
				$section_name = 'Module';
				break;

			case 'lesson' :
				$section_name = 'Lesson';
				break;

			case 'custom' :
				$section_name = esc_html( $section_name_custom );
					break;

			case 'none':
				$section_name = '';
				break;

			default:
			case 'section' :
				$section_name = 'Section';
				break;

		endswitch;

			return $section_name;

	}

	/**
	* Adds a plurlized version of the convention name
	* function found in get_course_content_name_convention()
	*
	* @since 0.1.16
	* @return $section_name_plural - (string)
	*/

	static public function get_course_content_name_convention_plural() {

		$section_name_conv 	= UBC_WP_CLF_Lite::get_course_content_name_convention();

		$section_name_plural = ! empty( $section_name_conv ) ? $section_name_conv .'s' : '';

			return $section_name_plural;

	}

	public function ubc_wp_clf_lite_bbp_admin_links( $array, $r_id ) {

		$array['reply'] = bbp_get_topic_reply_link( array(
			'reply_text' => __( 'Reply to this topic', 'ubc-wp-clf-lite' ),
		) );

		return $array;

	}

}/* class UBC_CLF_Lite() */

// Initialize our child theme changes
add_action( 'after_setup_theme', 'after_setup_theme__ubc_clf_lite_init', 15 );

/**
 * Initialize the UBC_CLF_Lite class on after_setup_theme so we're
 * up and running AFTER the parent theme (priority 15)
 *
 * @since 1.0.0
 *
 * @param null
 * @return null
 */

function after_setup_theme__ubc_clf_lite_init() {

	$UBC_CLF_Lite = new UBC_WP_CLF_Lite();
	$UBC_CLF_Lite->init();

}/* after_setup_theme__ubc_clf_lite_init() */


/**
 * Customizer additions.
 */
require get_stylesheet_directory() . '/inc/customizer-ubc-wp-clf-lite.php';

/**
 * Theme Hook Alliance hooks
 *
 */
require get_stylesheet_directory() . '/inc/tha-hooks.php';

/**
 * content classes
 *
 */
require get_stylesheet_directory() . '/inc/content-classes.php';

/**
 * styles and scripts
 *
 */
require get_stylesheet_directory() . '/inc/scripts-styles.php';

/**
 * comments callback template
 *
 */
require get_stylesheet_directory() . '/inc/comments-callback.php';

/**
 * add BBPress configurations
 *
 */
require get_stylesheet_directory() . '/inc/bbp.php';

/**
 * add WordPress settings
 *
 */
require get_stylesheet_directory() . '/inc/add-settings.php';

/**
 * add theme support options
 *
 */
require get_stylesheet_directory() . '/inc/theme-support.php';

/**
 * add clf cdn support
 *
 */

require get_stylesheet_directory() . '/inc/ubc-clf-cdn-support.php';
