<?php
class UBC_CLF_Lite_Customizer {

	/**
	 * Set up our actions and filters
	 *
	 * @since 0.1.1
	 *
	 * @param null
	 * @return null
	 */

	public function init() {

		//Edit customizer
		add_action( 'customize_register', array( $this, 'customizer_remove_defaults_customize' ), 10, 2 );
		add_action( 'customize_register', array( $this, 'ubc_customizer_add_customizer_settings_controls_frontpage' ), 10, 2 );
		add_action( 'customize_register', array( $this, 'ubc_customizer_add_customizer_settings_controls_course_info' ), 10, 2 );
		add_action( 'customize_register', array( $this, 'ubc_wp_clf_lite_color_theme_customizer' ), 10, 2 );
		add_action( 'customize_register', array( $this, 'ubc_customizer_add_customizer_settings_controls_course_content' ), 10, 2 );
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'hide_reveal_customizer_controls' ), 10, 2 );

	}/* init() */

	/**
	 * Enqueue admin script to allow hide and reveal input content
	 *
	 * @since 0.1.18
	 *
	 * @param null
	 * @return null
	 */

	public function hide_reveal_customizer_controls() {

	    wp_enqueue_script( 'customizer-controls', get_stylesheet_directory_uri() . '/js/admin/customizer.js', array( 'jquery' ), '20170412', true );

	}

	/**
	 * Customizer setups
	 *
	 * @since 0.1.1
	 *
	 * @param $wp_customize
	 * @return null
	 */

	public function customizer_remove_defaults_customize( $wp_customize ) {

			//Remove unwanted sections
		$wp_customize->remove_section( 'themes' );
		$wp_customize->remove_section( 'title_tagline' );
		$wp_customize->remove_section( 'background_image' );
		$wp_customize->remove_section( 'static_front_page' );
		$wp_customize->remove_section( 'custom_css' );

		//Remove unwanted controls
		$wp_customize->remove_control( 'blogdescription' );
		$wp_customize->remove_control( 'header_textcolor' );
		$wp_customize->remove_control( 'display_header_text' );
		$wp_customize->remove_control( 'background_color' );

	}

	/**
	 * Add setting and contols for frontpage customizer
	 *
	 * @since 0.1.18
	 *
	 * @param $wp_customize
	 * @return null
	 */

	public function ubc_customizer_add_customizer_settings_controls_frontpage( $wp_customize ) {

		$wp_customize->add_section( 'static_front_page_custom', array(
			'title' 					=> __( 'Home page', 'ubc-wp-clf-lite' ),
			'priority' 				=> 36,
			'description' 		=> __( 'Please select what should be shown on the courses front page.', 'ubc-wp-clf-lite' ),
		) );

		$wp_customize->add_setting( 'show_on_front', array(
			'default' 		=> get_option( 'show_on_front' ),
			'capability' 	=> 'manage_options',
			'type' 				=> 'option',
		) );

		$wp_customize->add_control( 'show_on_front', array(
			'label' 	=> __( 'Front page displays', 'ubc-wp-clf-lite' ),
			'section' => 'static_front_page_custom',
			'type' 		=> 'radio',
			'choices' => array(
				'sections'	 => __( 'Course section list', 'ubc-wp-clf-lite' ),
				'posts'		 	 => __( 'Your latest posts', 'ubc-wp-clf-lite' ),
				'page' 		   => __( 'A static page', 'ubc-wp-clf-lite' ),
				// 'current'		 => 'Currently set to ' . get_option( 'show_on_front' ),
			),
		) );

		$wp_customize->add_setting( 'page_on_front', array(
			'type'       => 'option',
			'capability' => 'manage_options',
		) );

		$wp_customize->add_control( 'page_on_front', array(
			'label' 					=> __( 'Front page', 'ubc-wp-clf-lite' ),
			'section' 				=> 'static_front_page_custom',
			'type' 						=> 'dropdown-pages',
			'allow_addition'  => true,
		) );

		$wp_customize->add_setting( 'page_for_posts', array(
			'type' 				=> 'option',
			'capability'  => 'manage_options',
		) );

		$wp_customize->add_control( 'page_for_posts', array(
			'label' 					=> __( 'Posts page', 'ubc-wp-clf-lite' ),
			'section' 				=> 'static_front_page_custom',
			'type' 						=> 'dropdown-pages',
			'allow_addition'  => true,
		) );

	}

	/**
	 * Add setting and contols for course info
	 *
	 * @since 0.1.18
	 *
	 * @param $wp_customize
	 * @return null
	 */

	public function ubc_customizer_add_customizer_settings_controls_course_info( $wp_customize ) {

		$faculties = \UBC\Press\Utils::get_faculty_list();

		$site_title = get_bloginfo( 'name' );

		// Add Section for Course info
		// $args for setion
		$args_add_section_course_info = array(
				'title' 			=> __( 'Site Information', 'ubc-wp-clf-lite' ),
				'description' => __( 'Information related to the course.', 'ubc-wp-clf-lite' ),
				'priority' 		=> 35,
		);
		// customizer section
		$wp_customize->add_section( 'wp_clf_lite_customize_course_info_box', $args_add_section_course_info );

		// Course title
		// $args for setting
		$args_course_title_setting = array(
			'default' 		=> __( 'Title', 'ubc-wp-clf-lite' ),
			'capability'	=> 'edit_theme_options',
		);
		// $args for control
		$args_course_title_control = array(
			'label'				=> __( 'Enter the courses title.', 'ubc-wp-clf-lite' ),
			'description'	=> __( 'The name of the course.', 'ubc-wp-clf-lite' ),
			'section'			=> 'wp_clf_lite_customize_course_info_box',
			'type'				=> 'text',
			'default'			=> $site_title,
		);
		// customizer settings and controls
		$wp_customize->add_setting( 'course_title', $args_course_title_setting );
		$wp_customize->add_control( 'course_title', $args_course_title_control );

		// add setting to to wp_clf_lite_customize_course_info_box section
		$wp_customize->add_setting(
			'faculty_school',
			array(
					'default' => 'Faculty or School',
			)
		);
		// add controller to faculty_school setting
		// *** STILL NEEDS SANITATION http://themefoundation.com/wordpress-theme-customizer/
		$wp_customize->add_control(
			'faculty_school',
			array(
					'label' 			=> __( 'Faculty or School', 'ubc-wp-clf-lite' ),
					'section' 		=> 'wp_clf_lite_customize_course_info_box',
					'type' 				=> 'select',
					'choices' 		=> $faculties,
			)
		);

		// Course description metabox
		// $args for setting
		$args_course_desc_setting = array( 'default' => 'Please write the courses description.', );
		// $args for add_control
		$args_course_desc_control = array(
				'label' => __( 'Course Description', 'ubc-wp-clf-lite' ),
				'section' => 'wp_clf_lite_customize_course_info_box',
				'type' => 'textarea',
		);
		// customizer settings and controls
		$wp_customize->add_setting( 'course_decription', $args_course_desc_setting );
		$wp_customize->add_control( 'course_decription', $args_course_desc_control );

	} // ubc_customizer_add_customizer_settings_controls_course_info()

	/**
	 * customizer course content setup
	 *
	 * @since 0.1.18
	 *
	 * @param $wp_customize
	 * @return null
	 */

	public function ubc_customizer_add_customizer_settings_controls_course_content( $wp_customize ) {

		// Add Section for Course info
		// $args for setion
		$args_add_section_course_content = array(
				'title' 			=> __( 'Customize Site', 'ubc-wp-clf-lite' ),
				'description' => __( 'Customize site details.	', 'ubc-wp-clf-lite' ),
				'priority' 		=> 36,
		);
		// customizer section
		$wp_customize->add_section( 'wp_clf_lite_customize_course_content_box', $args_add_section_course_content );

		$custom_site_type_settings = array(
			'default' 		=> __( 'Course', 'ubc-wp-clf-lite' ),
			'capability'	=> 'edit_theme_options',
		);

		// $args for add_control
		$custom_course_reference = array(
			'label'				=> __( 'Site type', 'ubc-wp-clf-lite' ),
			'section'			=> 'wp_clf_lite_customize_course_content_box',
			'type'				=> 'text',
		);
			$wp_customize->add_setting( 'site_type_convention', $custom_site_type_settings );
			$wp_customize->add_control( 'site_type_convention', $custom_course_reference );

		// Section frontend name conventions
		// $args for add_setting
		$args_convetions_settings = array(
			'default' => 'section',
		);
		// options array
		$args_convetions_control_choices = array(
				'section' 	=> __( 'Section', 'ubc-wp-clf-lite' ),
				'module' 		=> __( 'Module', 'ubc-wp-clf-lite' ),
				'lesson' 		=> __( 'Lesson', 'ubc-wp-clf-lite' ),
				'none' 			=> __( 'None', 'ubc-wp-clf-lite' ),
				'custom' 		=> __( 'Custom (Show custom input)', 'ubc-wp-clf-lite' ),
		);
		// $args for add_control
		$args_convetions_control = array(
			'label' 			=> __( 'Course content grouping naming conventions', 'ubc-wp-clf-lite' ),
			'description'	=> __( 'UBC Course spaces uses the nomenclature, section or subsection, to describe groupings of course material. You can change that naming convention for the courses frontend.  ', 'ubc-wp-clf-lite' ),
			'section' 		=> 'wp_clf_lite_customize_course_content_box',
			'type' 				=> 'select',
			'choices' 		=> $args_convetions_control_choices,
		);
		// customizer settings and controls
			$wp_customize->add_setting( 'section_name_convention', $args_convetions_settings );
			$wp_customize->add_control( 'section_name_convention', $args_convetions_control );

		// Custom naming of sections
		// $args for add_setting
		$args_conventions_custom_settings = array(
			'default' 		=> __( 'Section', 'ubc-wp-clf-lite' ),
			'capability'	=> 'edit_theme_options',
		);
		// $args for add_control
		$args_conventions_custom_control = array(
			'label'				=> __( 'Custom section name.', 'ubc-wp-clf-lite' ),
			'section'			=> 'wp_clf_lite_customize_course_content_box',
			'type'				=> 'text',
		);
		// customizer settings and controls
			$wp_customize->add_setting( 'section_name_convention_custom', $args_conventions_custom_settings );
			$wp_customize->add_control( 'section_name_convention_custom', $args_conventions_custom_control );

		// Number sections
		// $args for add_setting
		$args_numbering_accordion_custom_settings = array(
			'default' 		=> __( 'no', 'ubc-wp-clf-lite' ),
			'capability'	=> 'edit_theme_options',
		);
		// $args for radio options
		$args_numbering_accordions_radio_options = array(
			'no' 	=> 'No',
			'yes'	=> 'Yes',
		);
		// $args for add_control
		$args_numbering_custom_control = array(
			'label'				=> __( 'Numbered section content', 'ubc-wp-clf-lite' ),
			'description'	=> __( 'Number each top section of course listings.', 'ubc-wp-clf-lite' ),
			'section'			=> 'wp_clf_lite_customize_course_content_box',
			'type' 				=> 'radio',
			'choices'			=> $args_numbering_accordions_radio_options,
		);

				// customizer settings and controls
				$wp_customize->add_setting( 'section_name_convention_numbering', $args_numbering_accordion_custom_settings );
				$wp_customize->add_control( 'section_name_convention_numbering', $args_numbering_custom_control );

			// // accordion sections
			// // $args for add_control
			// $args_accordion_custom_control = array(
			// 	'label'				=> __( 'Accordions', 'ubc-wp-clf-lite' ),
			// 	'description'	=> __( 'Course content listings are displayed in an accordion.', 'ubc-wp-clf-lite' ),
			// 	'section'			=> 'wp_clf_lite_customize_course_content_box',
			// 	'type' 				=> 'radio',
			// 	'choices'			=> $args_numbering_accordions_radio_options,
			// );

			// customizer settings and controls
				$wp_customize->add_setting( 'section_name_convention_accordion', $args_numbering_accordion_custom_settings );
				// $wp_customize->add_control( 'section_name_convention_accordion', $args_accordion_custom_control );

	}/* ubc_customizer_add_customizer_settings_controls_course_content() */



	public function customizer_text_field_sanatize( $input ) {

			return wp_kses_post( force_balance_tags( $input ) );

	}

	/**
	 * Set a default if the theme mod
	 *
	 * @since 0.0.18
	 */

	public function ubc_theme_mod_theme_selected() {

		$ubc_clf_lite_theme_select_section = get_theme_mod( 'ubc_clf_lite_theme_select_section' );

		$course_theme_scheme_selected = ! empty( $ubc_clf_lite_theme_select_section ) ? $ubc_clf_lite_theme_select_section : 'default-theme';

			return $course_theme_scheme_selected;

	}

	/**
	 * Add course theme stylesheet select to customizer
	 *
	 * @since 0.0.18
	 */

	public function ubc_wp_clf_lite_color_theme_customizer( $wp_customize ) {

		$theme_color_scheme_options_array = array(
			'default-theme'	 	=> __( 'Default theme', 'ubc-wp-clf-lite' ),
			'dark-theme'		 	=> __( 'Dark theme', 'ubc-wp-clf-lite' ),
			// 'ubc-theme'		 		=> __( 'Pure UBC', 'ubc-wp-clf-lite' ),
		);

		$wp_customize->add_section( 'ubc_clf_lite_theme_select_section', array(
			'title' 					=> __( 'Color scheme', 'ubc-wp-clf-lite' ),
			'priority' 				=> 56,
			'description' 		=> __( 'Select color scheme for course.', 'ubc-wp-clf-lite' ),
		) );

		$wp_customize->add_setting( 'ubc_clf_lite_theme_select_section', array(
			'default' 		=> $this->ubc_theme_mod_theme_selected(),
			'capability' 	=> 'manage_options',
			// 'type' 				=> 'option',
		) );

		$wp_customize->add_control(
			new WP_Customize_Control(
				$wp_customize,
				'ubc_clf_lite_theme_select_section',
				array(
					'label' 		=> __( 'Select color scheme', 'ubc-wp-clf-lite' ),
					'section' 	=> 'ubc_clf_lite_theme_select_section',
					'type' 			=> 'radio',
					'choices' 	=> $theme_color_scheme_options_array,
				)
			)
		);

	}

}/* class UBC_CLF_Lite_Customizer() */

// Initialize our child theme changes
add_action( 'after_setup_theme', 'after_setup_theme__ubc_clf_lite_customizer_init', 15 );

/**
 * Initialize the UBC_CLF_Lite_Customizer class on after_setup_theme so we're
 * up and running AFTER the parent theme (priority 15)
 *
 * @since 1.0.0
 *
 * @param null
 * @return null
 */

function after_setup_theme__ubc_clf_lite_customizer_init() {

	$UBC_CLF_Lite_Customizer = new UBC_CLF_Lite_Customizer();
	$UBC_CLF_Lite_Customizer->init();

}/* after_setup_theme__ubc_clf_lite_init() */
